==> nui_core-0.0.127.tar.gz: lib/config/nui_app_config.dart <==
import 'package:nui_core/data/nui_ent.dart';

class NUIAppConfig extends NUIEnt{
  NUIAppConfig.empty();
  NUIAppConfig({
    this.appId, this.versionCode, this.versionName, this.releaseVersion, this.name, this.oneSignalAppId, this.oneSignalAppRESTKey, this.baseURL
  });
  int versionCode;
  String appId;
  String versionName;
  String releaseVersion;
  String name;
  String oneSignalAppId;
  String oneSignalAppRESTKey;
  String baseURL;

  String getVersionWithRelease(){
    return versionName + "-" + releaseVersion;
  }

  @override
  NUIEntMapper mapper() => NUIAppConfigEntity();
}

class NUIAppConfigEntity extends NUIEntMapper<NUIAppConfig>{
  @override
  String entityName() => "NUIAppConfig";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIAppConfig>(name: "appId", type: NUIEntType.STRING, setter: (data, value) => data.appId = value, getter: (data) => data.appId),
      NUIEntField<NUIAppConfig>(name: "versionCode", type: NUIEntType.INTEGER, setter: (data, value) => data.versionCode = value, getter: (data) => data.versionCode),
      NUIEntField<NUIAppConfig>(name: "versionName", type: NUIEntType.STRING, setter: (data, value) => data.versionName = value, getter: (data) => data.versionName),
      NUIEntField<NUIAppConfig>(name: "releaseVersion", type: NUIEntType.STRING, setter: (data, value) => data.releaseVersion = value, getter: (data) => data.releaseVersion),
      NUIEntField<NUIAppConfig>(name: "name", type: NUIEntType.STRING, setter: (data, value) => data.name = value, getter: (data) => data.name),
      NUIEntField<NUIAppConfig>(name: "oneSignalAppId", type: NUIEntType.STRING, setter: (data, value) => data.oneSignalAppId = value, getter: (data) => data.oneSignalAppId),
      NUIEntField<NUIAppConfig>(name: "oneSignalAppRESTKey", type: NUIEntType.STRING, setter: (data, value) => data.oneSignalAppRESTKey = value, getter: (data) => data.oneSignalAppRESTKey),
      NUIEntField<NUIAppConfig>(name: "baseURL", type: NUIEntType.STRING, setter: (data, value) => data.baseURL = value, getter: (data) => data.baseURL),
    ];
  }

  @override
  NUIAppConfig newInstance() => NUIAppConfig.empty();
}

==> nui_core-1.0.15.tar.gz: lib/config/nui_app_config.dart <==
import 'package:nui_core/data/nui_ent.dart';

class NUIAppConfig extends NUIEnt{
  NUIAppConfig.empty();
  NUIAppConfig({
    this.appId, this.versionCode, this.versionName, this.releaseVersion, this.name, this.oneSignalAppId, this.oneSignalAppRESTKey, this.baseURL
  });
  int? versionCode;
  String? appId;
  String? versionName;
  String? releaseVersion;
  String? name;
  String? oneSignalAppId;
  String? oneSignalAppRESTKey;
  String? baseURL;

  String getVersionWithRelease(){
    return (versionName ?? "") + "-" + (releaseVersion ?? "");
  }

  @override
  NUIEntMapper mapper() => NUIAppConfigEntity();
}

class NUIAppConfigEntity extends NUIEntMapper<NUIAppConfig>{
  @override
  String entityName() => "NUIAppConfig";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIAppConfig>(name: "appId", type: NUIEntType.STRING, setter: (data, value) => data.appId = value, getter: (data) => data.appId),
      NUIEntField<NUIAppConfig>(name: "versionCode", type: NUIEntType.INTEGER, setter: (data, value) => data.versionCode = value, getter: (data) => data.versionCode),
      NUIEntField<NUIAppConfig>(name: "versionName", type: NUIEntType.STRING, setter: (data, value) => data.versionName = value, getter: (data) => data.versionName),
      NUIEntField<NUIAppConfig>(name: "releaseVersion", type: NUIEntType.STRING, setter: (data, value) => data.releaseVersion = value, getter: (data) => data.releaseVersion),
      NUIEntField<NUIAppConfig>(name: "name", type: NUIEntType.STRING, setter: (data, value) => data.name = value, getter: (data) => data.name),
      NUIEntField<NUIAppConfig>(name: "oneSignalAppId", type: NUIEntType.STRING, setter: (data, value) => data.oneSignalAppId = value, getter: (data) => data.oneSignalAppId),
      NUIEntField<NUIAppConfig>(name: "oneSignalAppRESTKey", type: NUIEntType.STRING, setter: (data, value) => data.oneSignalAppRESTKey = value, getter: (data) => data.oneSignalAppRESTKey),
      NUIEntField<NUIAppConfig>(name: "baseURL", type: NUIEntType.STRING, setter: (data, value) => data.baseURL = value, getter: (data) => data.baseURL),
    ];
  }

  @override
  NUIAppConfig newInstance() => NUIAppConfig.empty();
}
